==> ejc-jlincome-impl-3.0.0-20240518.071702-97-sources.jar: com/ejianc/business/jlincome/bid/bean/BusinessEntity.java <==
package com.ejianc.business.jlincome.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 投标-商机登记
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_business")
public class BusinessEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态 ：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="org_id")
    private Long orgId; // 组织/区域主键
    @TableField(value="org_name")
    private String orgName; // 组织名称/区域名称
    @TableField(value="org_code")
    private String orgCode; // 组织编码/区域编码
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="project_type_id")
    private Long projectTypeId; // 项目类型
    @TableField(value="project_type_name")
    private String projectTypeName; // 项目类型名称
    @TableField(value="product_type")
    private String productType; // 产品类型
    @TableField(value="product_type_name")
    private String productTypeName; // 产品类型名称
    @TableField(value="info_source_id")
    private Long infoSourceId; // 信息来源
    @TableField(value="info_source_name")
    private String infoSourceName; // 信息来源名称
    @TableField(value="sale_leader_id")
    private Long saleLeaderId; // 销售负责人
    @TableField(value="sale_leader_name")
    private String saleLeaderName; // 销售负责人名称
    @TableField(value="sale_leader_phone")
    private String saleLeaderPhone; // 销售负责人联系电话
    @TableField(value="entry_fee")
    private BigDecimal entryFee; // 报名费用
    @TableField(value="business_stage")
    private String businessStage; // 商机阶段（0：跟踪 1：中标 2：放弃)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="custom_name")
    private String customName; // 客户名称
    @TableField(value="custom_link_name")
    private String customLinkName; // 客户联系人
    @TableField(value="custom_link_phone")
    private String customLinkPhone; // 客户联系人电话
    @TableField(value="plan_bid_date")
    private Date planBidDate; // 预计招标日期
    @TableField(value="plan_deliver_date")
    private Date planDeliverDate; // 预计交货日期
    @TableField(value="entry_end_date")
    private Date entryEndDate; // 报名截至日期
    @TableField(value="plan_bid_open_date")
    private Date planBidOpenDate; // 预计开标日期
    @TableField(value="bid_file_plan_receive_date")
    private Date bidFilePlanReceiveDate; // 招标文件预计接收日期
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="num")
    private String num; // 数量
    @TableField(value="tender_mode_id")
    private Long tenderModeId; // 招标方式
    @TableField(value="tender_mode_name")
    private String tenderModeName; // 招标方式名称
    @TableField(value="detailed_address")
    private String detailedAddress; // 详细地址
    @TableField(value="area")
    private String area; // 区域
    @TableField(value="project_situation")
    private String projectSituation; // 工程概况
    @TableField(value="abandon_flag")
    private Boolean abandonFlag; // 是否放弃（0：否 1：是）
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getProjectTypeId() {
        return projectTypeId;
    }

    public void setProjectTypeId(Long projectTypeId) {
        this.projectTypeId = projectTypeId;
    }
    public String getProjectTypeName() {
        return projectTypeName;
    }

    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }
    public String getProductType() {
        return productType;
    }

    public void setProductType(String productType) {
        this.productType = productType;
    }
    public String getProductTypeName() {
        return productTypeName;
    }

    public void setProductTypeName(String productTypeName) {
        this.productTypeName = productTypeName;
    }
    public Long getInfoSourceId() {
        return infoSourceId;
    }

    public void setInfoSourceId(Long infoSourceId) {
        this.infoSourceId = infoSourceId;
    }
    public String getInfoSourceName() {
        return infoSourceName;
    }

    public void setInfoSourceName(String infoSourceName) {
        this.infoSourceName = infoSourceName;
    }
    public Long getSaleLeaderId() {
        return saleLeaderId;
    }

    public void setSaleLeaderId(Long saleLeaderId) {
        this.saleLeaderId = saleLeaderId;
    }
    public String getSaleLeaderName() {
        return saleLeaderName;
    }

    public void setSaleLeaderName(String saleLeaderName) {
        this.saleLeaderName = saleLeaderName;
    }
    public String getSaleLeaderPhone() {
        return saleLeaderPhone;
    }

    public void setSaleLeaderPhone(String saleLeaderPhone) {
        this.saleLeaderPhone = saleLeaderPhone;
    }
    public BigDecimal getEntryFee() {
        return entryFee;
    }

    public void setEntryFee(BigDecimal entryFee) {
        this.entryFee = entryFee;
    }
    public String getBusinessStage() {
        return businessStage;
    }

    public void setBusinessStage(String businessStage) {
        this.businessStage = businessStage;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getCustomName() {
        return customName;
    }

    public void setCustomName(String customName) {
        this.customName = customName;
    }
    public String getCustomLinkName() {
        return customLinkName;
    }

    public void setCustomLinkName(String customLinkName) {
        this.customLinkName = customLinkName;
    }
    public String getCustomLinkPhone() {
        return customLinkPhone;
    }

    public void setCustomLinkPhone(String customLinkPhone) {
        this.customLinkPhone = customLinkPhone;
    }
    public Date getPlanBidDate() {
        return planBidDate;
    }

    public void setPlanBidDate(Date planBidDate) {
        this.planBidDate = planBidDate;
    }
    public Date getPlanDeliverDate() {
        return planDeliverDate;
    }

    public void setPlanDeliverDate(Date planDeliverDate) {
        this.planDeliverDate = planDeliverDate;
    }
    public Date getEntryEndDate() {
        return entryEndDate;
    }

    public void setEntryEndDate(Date entryEndDate) {
        this.entryEndDate = entryEndDate;
    }
    public Date getPlanBidOpenDate() {
        return planBidOpenDate;
    }

    public void setPlanBidOpenDate(Date planBidOpenDate) {
        this.planBidOpenDate = planBidOpenDate;
    }
    public Date getBidFilePlanReceiveDate() {
        return bidFilePlanReceiveDate;
    }

    public void setBidFilePlanReceiveDate(Date bidFilePlanReceiveDate) {
        this.bidFilePlanReceiveDate = bidFilePlanReceiveDate;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getNum() {
        return num;
    }

    public void setNum(String num) {
        this.num = num;
    }
    public Long getTenderModeId() {
        return tenderModeId;
    }

    public void setTenderModeId(Long tenderModeId) {
        this.tenderModeId = tenderModeId;
    }
    public String getTenderModeName() {
        return tenderModeName;
    }

    public void setTenderModeName(String tenderModeName) {
        this.tenderModeName = tenderModeName;
    }
    public String getDetailedAddress() {
        return detailedAddress;
    }

    public void setDetailedAddress(String detailedAddress) {
        this.detailedAddress = detailedAddress;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public String getProjectSituation() {
        return projectSituation;
    }

    public void setProjectSituation(String projectSituation) {
        this.projectSituation = projectSituation;
    }

    public Boolean getAbandonFlag() {
        return abandonFlag;
    }

    public void setAbandonFlag(Boolean abandonFlag) {
        this.abandonFlag = abandonFlag;
    }
}

==> ejc-jlincome-impl-3.0.0-20240919.090513-205-sources.jar: com/ejianc/business/jlincome/bid/bean/BusinessEntity.java <==
package com.ejianc.business.jlincome.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 投标-商机登记
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_business")
public class BusinessEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态 ：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="org_id")
    private Long orgId; // 组织/区域主键
    @TableField(value="org_name")
    private String orgName; // 组织名称/区域名称
    @TableField(value="org_code")
    private String orgCode; // 组织编码/区域编码
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="project_type_id")
    private Long projectTypeId; // 项目类型
    @TableField(value="project_type_name")
    private String projectTypeName; // 项目类型名称
    @TableField(value="product_type")
    private String productType; // 产品类型
    @TableField(value="product_type_name")
    private String productTypeName; // 产品类型名称
    @TableField(value="info_source_id")
    private Long infoSourceId; // 信息来源
    @TableField(value="info_source_name")
    private String infoSourceName; // 信息来源名称
    @TableField(value="sale_leader_id")
    private Long saleLeaderId; // 销售负责人
    @TableField(value="sale_leader_name")
    private String saleLeaderName; // 销售负责人名称
    @TableField(value="sale_leader_phone")
    private String saleLeaderPhone; // 销售负责人联系电话
    @TableField(value="entry_fee")
    private BigDecimal entryFee; // 报名费用
    @TableField(value="business_stage")
    private String businessStage; // 商机阶段（0：跟踪 1：中标 2：放弃)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="custom_name")
    private String customName; // 客户名称
    @TableField(value="custom_link_name")
    private String customLinkName; // 客户联系人
    @TableField(value="custom_link_phone")
    private String customLinkPhone; // 客户联系人电话
    @TableField(value="plan_bid_date")
    private Date planBidDate; // 预计招标日期
    @TableField(value="plan_deliver_date")
    private Date planDeliverDate; // 预计交货日期
    @TableField(value="entry_end_date")
    private Date entryEndDate; // 报名截至日期
    @TableField(value="plan_bid_open_date")
    private Date planBidOpenDate; // 预计开标日期
    @TableField(value="bid_file_plan_receive_date")
    private Date bidFilePlanReceiveDate; // 招标文件预计接收日期
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="num")
    private String num; // 数量
    @TableField(value="tender_mode_id")
    private Long tenderModeId; // 招标方式
    @TableField(value="tender_mode_name")
    private String tenderModeName; // 招标方式名称
    @TableField(value="detailed_address")
    private String detailedAddress; // 详细地址
    @TableField(value="area")
    private String area; // 区域
    @TableField(value="project_situation")
    private String projectSituation; // 工程概况
    @TableField(value="abandon_flag")
    private Boolean abandonFlag; // 是否放弃（0：否 1：是）
    @TableField(value="business_round")
    private Integer businessRound; // 商机阶段 ：0项目立项，1设计方案，2业主招标，3总包招标，4合同签订

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getProjectTypeId() {
        return projectTypeId;
    }

    public void setProjectTypeId(Long projectTypeId) {
        this.projectTypeId = projectTypeId;
    }
    public String getProjectTypeName() {
        return projectTypeName;
    }

    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }
    public String getProductType() {
        return productType;
    }

    public void setProductType(String productType) {
        this.productType = productType;
    }
    public String getProductTypeName() {
        return productTypeName;
    }

    public void setProductTypeName(String productTypeName) {
        this.productTypeName = productTypeName;
    }
    public Long getInfoSourceId() {
        return infoSourceId;
    }

    public void setInfoSourceId(Long infoSourceId) {
        this.infoSourceId = infoSourceId;
    }
    public String getInfoSourceName() {
        return infoSourceName;
    }

    public void setInfoSourceName(String infoSourceName) {
        this.infoSourceName = infoSourceName;
    }
    public Long getSaleLeaderId() {
        return saleLeaderId;
    }

    public void setSaleLeaderId(Long saleLeaderId) {
        this.saleLeaderId = saleLeaderId;
    }
    public String getSaleLeaderName() {
        return saleLeaderName;
    }

    public void setSaleLeaderName(String saleLeaderName) {
        this.saleLeaderName = saleLeaderName;
    }
    public String getSaleLeaderPhone() {
        return saleLeaderPhone;
    }

    public void setSaleLeaderPhone(String saleLeaderPhone) {
        this.saleLeaderPhone = saleLeaderPhone;
    }
    public BigDecimal getEntryFee() {
        return entryFee;
    }

    public void setEntryFee(BigDecimal entryFee) {
        this.entryFee = entryFee;
    }
    public String getBusinessStage() {
        return businessStage;
    }

    public void setBusinessStage(String businessStage) {
        this.businessStage = businessStage;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getCustomName() {
        return customName;
    }

    public void setCustomName(String customName) {
        this.customName = customName;
    }
    public String getCustomLinkName() {
        return customLinkName;
    }

    public void setCustomLinkName(String customLinkName) {
        this.customLinkName = customLinkName;
    }
    public String getCustomLinkPhone() {
        return customLinkPhone;
    }

    public void setCustomLinkPhone(String customLinkPhone) {
        this.customLinkPhone = customLinkPhone;
    }
    public Date getPlanBidDate() {
        return planBidDate;
    }

    public void setPlanBidDate(Date planBidDate) {
        this.planBidDate = planBidDate;
    }
    public Date getPlanDeliverDate() {
        return planDeliverDate;
    }

    public void setPlanDeliverDate(Date planDeliverDate) {
        this.planDeliverDate = planDeliverDate;
    }
    public Date getEntryEndDate() {
        return entryEndDate;
    }

    public void setEntryEndDate(Date entryEndDate) {
        this.entryEndDate = entryEndDate;
    }
    public Date getPlanBidOpenDate() {
        return planBidOpenDate;
    }

    public void setPlanBidOpenDate(Date planBidOpenDate) {
        this.planBidOpenDate = planBidOpenDate;
    }
    public Date getBidFilePlanReceiveDate() {
        return bidFilePlanReceiveDate;
    }

    public void setBidFilePlanReceiveDate(Date bidFilePlanReceiveDate) {
        this.bidFilePlanReceiveDate = bidFilePlanReceiveDate;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getNum() {
        return num;
    }

    public void setNum(String num) {
        this.num = num;
    }
    public Long getTenderModeId() {
        return tenderModeId;
    }

    public void setTenderModeId(Long tenderModeId) {
        this.tenderModeId = tenderModeId;
    }
    public String getTenderModeName() {
        return tenderModeName;
    }

    public void setTenderModeName(String tenderModeName) {
        this.tenderModeName = tenderModeName;
    }
    public String getDetailedAddress() {
        return detailedAddress;
    }

    public void setDetailedAddress(String detailedAddress) {
        this.detailedAddress = detailedAddress;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public String getProjectSituation() {
        return projectSituation;
    }

    public void setProjectSituation(String projectSituation) {
        this.projectSituation = projectSituation;
    }

    public Boolean getAbandonFlag() {
        return abandonFlag;
    }

    public void setAbandonFlag(Boolean abandonFlag) {
        this.abandonFlag = abandonFlag;
    }

    public Integer getBusinessRound() {
        return businessRound;
    }

    public void setBusinessRound(Integer businessRound) {
        this.businessRound = businessRound;
    }
}
